@@ -5,7 +5,9 @@ pub mod tokens;
 mod parse_to_ast;
 mod scanner;
 mod parse_to_value;
+mod value;
 
 pub use parse_to_ast::*;
 pub use parse_to_value::*;
 pub use scanner::*;
+pub use value::*;
